# document.tcl: A document model based on TIM
# $Id: document.tcl,v 1.3 2000/05/02 00:01:28 johnr Exp $
#
# Author: John Reekie
#
# Copyright (c) 1998-2000 The Regents of the University of California.
# All rights reserved. See the file COPYRIGHT for details.
#


# Create the namespace for these procs
namespace eval document {
    set counter -1
    namespace export *
    namespace import ::tim::*
}

##########################################################################
#### init
#
# A stupid proc jsut to we can force loading of this file
#
proc document::init {} {
    ;# yawn
}

##########################################################################
#### create
#
# Create an document model is a model of a multi-file document.
# It can be used to create the document and maintain its structure
# without having to mess around with HTML links and stuff.
#
# The model has the following options:
#
# <dl>
#   <dt><b>-bgcolor</b> _color_
#   <dd>
#   The background color of each page. Default is white.
#
#   <dt><b>-directory</b> _string_
#   <dd>
#   The directory to place files into. If null, then the directory
#   will be the same as the directory of the <b>-modelpath</b> option.
#   If called from the <b>::document::htmlOutline</b> procedure, this
#   will be the same as the directory in which the document file
#   is contained.
#
#   <dt><b>-footer</b> _string_
#   <dd>
#   Text to be placed at the bottom of each page. This text will be
#   enclosed between the two comments <code>&lt;!--customfooter--&gt;</code>
#   and <code>&lt;!--/customfooter--&gt;</code>. This text will be automatically
#   replaced each time the document is reparsed.
#
#   <dt><b>-header</b> _string_
#   <dd>
#   Text to be placed in the header of each page. This may include
#   <meta> tags, <style> tags, or <link>. This text will be
#   enclosed between the two comments <code>&lt;!--header--&gt;</code>
#   and <code>&lt;!--/header--&gt;</code>. This text will be automatically
#   replaced each time the document is reparsed.
#
#   <dt><b>-imagedir</b> _directory_
#   <dd>
#   The location of the images for the navigation buttons.
#   This can either be absolute or relative; if relative, it
#   will be relative to the directory in which the files are
#   being placed.
#
#   <dt><b>-images</b> _filelist_
#   <dd>
#   The names of the image files. This is a list of file names
#   being the images for the top-level, previous, up-level, and next
#   navigation buttons.
#   The default is <code>{top.gif, previous.gif up.gif next.gif}</code>.
#
#   <dt><b>-inline</b> _boolean_
#   <dd>
#   The flag saying whether sections are contained within the
#   same file as this section or within separate files. See the
#   <b>-inline</b> option of the <b>section</b> type.
#
#   <dt><b>-suffix</b> _string_
#   <dd>
#   The file suffix. The default is ".html".
#
#   <dt><b>-template</b> _string_
#   <dd>
#   The template for a new document. The default gives a well-structured
#   document. It can be changed to changed the position of the
#   navigation bar and so on.
#
# </dl>
#
# The model has the following types:
#
# <dl>
# <dt><b>section</b> _name_
# <dd>
# A section of the document. Sections can either be contained
# within the file of the higher-level section, or within a separate
# file. The _name_ is the file name or anchor of this section.
# Sections have the following attributes:
#
#   <dl>
#   <dt><b>-inline</b> _boolean_
#   <dd>
#   The flag saying whether subsections are contained within the
#   same file as this section or within separate files. If within
#   separate files, the name of each section is used as the file
#   name, with the extension ".html". If within the same file,
#   the file will be generated within the same file, and the section
#   added to the table of contents with its name used as an anchor.
#
#   <dt><b>-title</b> _string_
#   <dd>
#   The section title.
#
#   </dl>
#
# </dl>
#
proc document::create {ns args} {
    # Create the model
    eval tim::create $ns

    # Import all commands
    namespace eval $ns {namespace import -force ::document::*} 

    # The footer for each file
    $ns configure -footer ""

    # The header for each file
    $ns configure -header ""

    # The background color
    $ns configure -bgcolor "#ffffff"

    # The directory to place files in
    $ns configure -directory ""

    # Flag to generate top-level sections in-line
    $ns configure -inline 0

    # The directory to find images in
    $ns configure -imagedir ""

    # The names of the image files
    $ns configure -images {top.gif previous.gif up.gif next.gif}

    # The file suffix
    $ns configure -suffix ".html"

    # The document template
    $ns configure -template {
<html>
<head>
<title></title>
</head>
<body>
<h1></h1>
</body>
</html>
    }

    # Override with passed options
    eval $ns configure $args

    # Create the types
    $ns define section \
            -inline 0 \
            -title ""

    # Set some initial variables
    # The current body of data
    set ${ns}::_body ""

    # The current table of contents
    set ${ns}::_contents ""

     # The data obtained from the input file
    set ${ns}::_data ""

    # An array of current options, for output generation
    array set ${ns}::_options {}
}







